summaryrefslogtreecommitdiff
path: root/ceilometer/image
diff options
context:
space:
mode:
authorDoug Hellmann <doug@doughellmann.com>2015-04-28 16:05:49 +0000
committerDoug Hellmann <doug@doughellmann.com>2015-04-28 16:22:05 +0000
commite41b259a1e635fcaf8d873c18602f2cbafd36020 (patch)
treecc80899f5ee3f44b01666811848cea077522e4f9 /ceilometer/image
parent1b593e9b009fe38e470aa8a6aa0eaa02adcaa3aa (diff)
downloadceilometer-e41b259a1e635fcaf8d873c18602f2cbafd36020.tar.gz
Drop use of 'oslo' namespace package.
The Oslo libraries have moved all of their code out of the 'oslo' namespace package into per-library packages. The namespace package was retained during kilo for backwards compatibility, but will be removed by the liberty-2 milestone. This change removes the use of the namespace package, replacing it with the new package names. The patches in the libraries will be put on hold until application patches have landed, or L2, whichever comes first. At that point, new versions of the libraries without namespace packages will be released as a major version update. Please merge this patch, or an equivalent, before L2 to avoid problems with those library releases. Blueprint: remove-namespace-packages https://blueprints.launchpad.net/oslo-incubator/+spec/remove-namespace-packages Change-Id: I2eeef93ee2e61a721c69f62add819f93f62f077d
Diffstat (limited to 'ceilometer/image')
-rw-r--r--ceilometer/image/notifications.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/ceilometer/image/notifications.py b/ceilometer/image/notifications.py
index 7f54f5bb..03ac5299 100644
--- a/ceilometer/image/notifications.py
+++ b/ceilometer/image/notifications.py
@@ -16,8 +16,8 @@
events.
"""
-import oslo.messaging
from oslo_config import cfg
+import oslo_messaging
from ceilometer.agent import plugin_base
from ceilometer import sample
@@ -37,12 +37,12 @@ class ImageBase(plugin_base.NotificationBase):
@staticmethod
def get_targets(conf):
"""Return a sequence of oslo.messaging.Target
This sequence is defining the exchange and topics to be connected for
this plugin.
"""
- return [oslo.messaging.Target(topic=topic,
+ return [oslo_messaging.Target(topic=topic,
exchange=conf.glance_control_exchange)
for topic in conf.notification_topics]
@@ -37,12 +37,12 @@ class ImageBase(plugin_base.NotificationBase):
def get_targets(conf):
- """Return a sequence of oslo.messaging.Target
+ """Return a sequence of oslo_messaging.Target
This sequence is defining the exchange and topics to be connected for
this plugin.